@@ -155,7 +155,7 @@ function getProgressMessage(progress)
     } else {
         return progress.readSize + ' / ' + progress.totalSize +
             ' (' + progress.getPercent() + '%) @ ' + progress.getSpeed() +
-            ' [Ĥ ' + progress.getRemainTime() + ']';
+            ' [' + progress.getRemainTime() + ']';
     }
 }
 
